@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -156,7 +156,7 @@ namespace libint2 {
     /// Return false if this object is invalid
     bool valid() const { return valid_; }
     /// Implements Hashable<unsigned>::key()
-    LIBINT2_UINT_LEAST64 key() const {
+    LIBINT2_UINT_LEAST64 key() const override {
       if (NDIM == 3u) {
         unsigned nxy = d_[1] + d_[2];
         unsigned l = nxy + d_[0];
@@ -268,9 +268,9 @@ namespace libint2 {
     OriginDerivative<3u>& deriv() { return deriv_; }
 
     /// Return a compact label
-    std::string label() const;
+    std::string label() const override;
     /// Returns the number of basis functions in the set
-    unsigned int num_bf() const { return (qn_[0]+1)*(qn_[0]+2)/2; };
+    unsigned int num_bf() const override { return (qn_[0]+1)*(qn_[0]+2)/2; }
     /// Returns the angular momentum
     unsigned int qn(unsigned int xyz=0) const { return qn_[0]; }
     /// returns the angular momentum
@@ -288,13 +288,13 @@ namespace libint2 {
     void pure_sh(bool p) { pure_sh_ = p; }
 
     /// Implementation of IncableBFSet::inc().
-    void inc(unsigned int xyz, unsigned int c = 1u);
+    void inc(unsigned int xyz, unsigned int c = 1u) override;
     /// Implementation of IncableBFSet::dec().
-    void dec(unsigned int xyz, unsigned int c = 1u);
+    void dec(unsigned int xyz, unsigned int c = 1u) override;
     /// Implements IncableBFSet::norm()
-    unsigned int norm() const;
+    unsigned int norm() const override;
     /// Implements Hashable<LIBINT2_UINT_LEAST64>::key()
-    LIBINT2_UINT_LEAST64 key() const {
+    LIBINT2_UINT_LEAST64 key() const override {
       if (is_unit()) return max_key-1;
       const LIBINT2_UINT_LEAST64 result =
              ((deriv().key() * 2 +
@@ -360,9 +360,9 @@ namespace libint2 {
     OriginDerivative<3u>& deriv() { return deriv_; }
 
     /// Return a compact label
-    std::string label() const;
+    std::string label() const override;
     /// Returns the number of basis functions in the set (always 1)
-    unsigned int num_bf() const { return 1; };
+    unsigned int num_bf() const override { return 1; }
     /// Returns the quantum number along \c axis
     unsigned int qn(unsigned int axis) const;
     unsigned int operator[](unsigned int axis) const {
@@ -379,13 +379,13 @@ namespace libint2 {
     bool operator==(const CGF&) const;
 
     /// Implementation of IncableBFSet::inc().
-    void inc(unsigned int xyz, unsigned int c = 1u);
+    void inc(unsigned int xyz, unsigned int c = 1u) override;
     /// Implementation of IncableBFSet::dec().
-    void dec(unsigned int xyz, unsigned int c = 1u);
+    void dec(unsigned int xyz, unsigned int c = 1u) override;
     /// Implements IncableBFSet::norm()
-    unsigned int norm() const;
+    unsigned int norm() const override;
     /// Implements Hashable<LIBINT2_UINT_LEAST64>::key()
-    LIBINT2_UINT_LEAST64 key() const {
+    LIBINT2_UINT_LEAST64 key() const override {
       if (is_unit()) return max_key-1;
       unsigned nxy = qn_[1] + qn_[2];
       unsigned l = nxy + qn_[0];
@@ -500,22 +500,22 @@ namespace libint2 {
     OriginDerivative<1u>& deriv() { return deriv_; }
 
     /// Return a compact label
-    std::string label() const {
+    std::string label() const override {
       // unit *functions* are treated as regular qn-0 functions so that (00|00)^(m) = (unit 0|00)^(m)
       std::ostringstream oss;
       oss << to_string(Axis) << qn_[0];
-      if (deriv_.zero() == false) oss << "_" << deriv_.label();
+      if (!deriv_.zero()) oss << "_" << deriv_.label();
 
       // I don't handle labels of contracted CGF1d because I don't think I need them
       // make sure just in case
-      assert(this->contracted() == false);
+      assert(!this->contracted());
 
       return oss.str();
     }
 
 
     /// Returns the number of basis functions in the set (always 1)
-    unsigned int num_bf() const { return 1; };
+    unsigned int num_bf() const override { return 1; }
     /// Returns the quantum number (what used to be "angular momentum")
     unsigned int qn(unsigned int dir = 0) const {
       assert(dir == 0);
@@ -534,14 +534,14 @@ namespace libint2 {
     }
 
     /// Implementation of IncableBFSet::inc().
-    void inc(unsigned int dir, unsigned int c = 1u) {
-      assert(is_unit() == false);
+    void inc(unsigned int dir, unsigned int c = 1u) override {
+      assert(!is_unit());
       assert(dir==0);
       if (valid())
         qn_[0] += c;
     }
     /// Implementation of IncableBFSet::dec().
-    void dec(unsigned int dir, unsigned int c = 1u) {
+    void dec(unsigned int dir, unsigned int c = 1u) override {
       if (is_unit()) { invalidate(); return; }
       assert(dir==0);
       if (valid()) {
@@ -553,9 +553,9 @@ namespace libint2 {
       }
     }
     /// Implements IncableBFSet::norm()
-    unsigned int norm() const { return qn_[0]; }
+    unsigned int norm() const override { return qn_[0]; }
     /// Implements Hashable<LIBINT2_UINT_LEAST64>::key()
-    LIBINT2_UINT_LEAST64 key() const {
+    LIBINT2_UINT_LEAST64 key() const override {
       if (is_unit()) return max_key-1;
       const LIBINT2_UINT_LEAST64 result =
             ( deriv().key() * 2ul +
@@ -666,24 +666,24 @@ namespace libint2 {
     OriginDerivative<1u>& deriv() { return deriv_; }
 
     /// Return a compact label
-    std::string label() const {
+    std::string label() const override {
       // unit *functions* are treated as regular qn-0 functions so that (00|00)^(m) = (unit 0|00)^(m)
       std::ostringstream oss;
       auto axis_label = to_string(Axis);
       axis_label[0] = std::toupper(axis_label[0]);
       oss << axis_label << qn_[0];
-      if (deriv_.zero() == false) oss << "_" << deriv_.label();
+      if (!deriv_.zero()) oss << "_" << deriv_.label();
 
       // I don't handle labels of contracted CGF1d because I don't think I need them
       // make sure just in case
-      assert(this->contracted() == false);
+      assert(!this->contracted());
 
       return oss.str();
     }
 
 
     /// Returns the number of basis functions in the set (always 1)
-    unsigned int num_bf() const { return qn_[0]+1; };
+    unsigned int num_bf() const override { return qn_[0]+1; }
     /// Returns the quantum number (what used to be "angular momentum")
     unsigned int qn(unsigned int dir=0) const {
       assert(dir == 0);
@@ -699,17 +699,17 @@ namespace libint2 {
     }
 
     /// Implementation of IncableBFSet::inc().
-    void inc(unsigned int dir, unsigned int c = 1u) {
+    void inc(unsigned int dir, unsigned int c = 1u) override {
       assert(false);
     }
     /// Implementation of IncableBFSet::dec().
-    void dec(unsigned int dir, unsigned int c = 1u) {
+    void dec(unsigned int dir, unsigned int c = 1u) override {
       assert(false);
     }
     /// Implements IncableBFSet::norm()
-    unsigned int norm() const { return qn_[0]; }
+    unsigned int norm() const override { return qn_[0]; }
     /// Implements Hashable<LIBINT2_UINT_LEAST64>::key()
-    LIBINT2_UINT_LEAST64 key() const {
+    LIBINT2_UINT_LEAST64 key() const override {
       if (is_unit()) return max_key-1;
       const LIBINT2_UINT_LEAST64 result =
             ( deriv().key() * 2ul +
