@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -24,8 +24,6 @@
 #include <generic_rr.h>
 #include <set>
 
-using namespace std;
-
 namespace libint2 {
 
   class CR_DerivGauss_GenericInstantiator {
@@ -103,11 +101,11 @@ namespace libint2 {
       /** Re-Implementation of GenericRecurrenceRelation::generate_label():
           CR Deriv relations are independent of m (it never appears anywhere in equations), hence
           to avoid generating identical code make sure that the (unique) label has m=0. */
-      std::string generate_label() const
+      std::string generate_label() const override
       {
         typedef typename TargetType::AuxIndexType mType;
         static SafePtr<mType> aux0(new mType(0u));
-        ostringstream os;
+        std::ostringstream os;
         os << descr() << "P" << part << to_string(where)
            << genintegralset_label(target_->bra(),target_->ket(),aux0,target_->oper());
         return os.str();
@@ -115,11 +113,11 @@ namespace libint2 {
 
 #if LIBINT_ENABLE_GENERIC_CODE
       /// Implementation of RecurrenceRelation::has_generic()
-      bool has_generic(const SafePtr<CompilationParameters>& cparams) const;
+      bool has_generic(const SafePtr<CompilationParameters>& cparams) const override;
       /// Implementation of RecurrenceRelation::generic_header()
-      std::string generic_header() const;
+      std::string generic_header() const override;
       /// Implementation of RecurrenceRelation::generic_instance()
-      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const;
+      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const override;
 #endif
     };
 
@@ -331,7 +329,7 @@ namespace libint2 {
     {
       std::ostringstream oss;
 
-      oss << "using namespace libint2;" << endl;
+      oss << "using namespace libint2;" << std::endl;
 
       BasisFunctionType sh(where == InBra ? target_->bra(part,0) : target_->ket(part,0));
 
