@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -24,6 +24,7 @@
 #include <codeblock.h>
 #include <default_params.h>
 
+using namespace std;
 using namespace libint2;
 
 namespace libint2 {
@@ -197,7 +198,7 @@ std::string
 CppCodeContext::code_prefix() const
 {
   if (cparams()->use_C_linking()) {
-    return "#ifdef __cplusplus\nextern \"C\" {\n#endif\n";
+    return "#ifdef __cplusplus\nLIBINT_PRAGMA_CLANG(diagnostic push)\nLIBINT_PRAGMA_CLANG(diagnostic ignored \"-Wunused-variable\")\nLIBINT_PRAGMA_GCC(diagnostic push)\nLIBINT_PRAGMA_GCC(diagnostic ignored \"-Wunused-variable\")\nextern \"C\" {\n#endif\n";
   }
   return "";
 }
@@ -206,7 +207,7 @@ std::string
 CppCodeContext::code_postfix() const
 {
   if (cparams()->use_C_linking()) {
-    return "#ifdef __cplusplus\n};\n#endif\n";
+    return "#ifdef __cplusplus\n};\nLIBINT_PRAGMA_CLANG(diagnostic pop)\nLIBINT_PRAGMA_GCC(diagnostic pop)\n#endif\n";
   }
   return "";
 }
@@ -216,7 +217,7 @@ CppCodeContext::copyright() const {
   std::ostringstream oss;
   using std::endl;
   oss << "/*"<< endl
-      << " *  Copyright (C) 2004-2019 Edward F. Valeev" << endl
+      << " *  Copyright (C) 2004-2021 Edward F. Valeev" << endl
       << " *" << endl
       << " *  This file is part of Libint." << endl
       << " *" << endl
@@ -270,7 +271,7 @@ CppCodeContext::declare(const std::string& type,
                         const std::string& name) const
 {
   ostringstream oss;
-  
+
   oss << type << " " << name << end_of_stat() << endl;
 
   return oss.str();
@@ -282,7 +283,7 @@ CppCodeContext::declare_v(const std::string& type,
 			  const std::string& nelem) const
 {
   ostringstream oss;
-  
+
   oss << type << " " << name << "[" << nelem << "]" << end_of_stat() << endl;
 
   return oss.str();
@@ -294,7 +295,7 @@ CppCodeContext::decldef(const std::string& type,
                         const std::string& value)
 {
   ostringstream oss;
-  
+
   oss << type << " " << assign(name,value);
 
   return oss.str();
@@ -320,7 +321,7 @@ CppCodeContext::assign_(const std::string& name,
 			bool accum)
 {
   ostringstream oss;
-  
+
   if (vectorize_) {
     std::string symb0 = unique_fp_name();
     std::string symb1 = unique_fp_name();
@@ -335,7 +336,7 @@ CppCodeContext::assign_(const std::string& name,
       <<  symbol_to_pointer(value) << end_of_stat() << endl;
       oss << "__assume_aligned(" << symb1 << ", 16)" << end_of_stat() << endl;
     }
-    
+
     oss << start_expr();
     oss << symb0 << "[v]" << (accum ? " += " : " = ")
     << (symb1_is_a_const ? value : symb1)
@@ -377,7 +378,7 @@ CppCodeContext::assign_binary_expr_(const std::string& name,
 				    bool accum)
 {
   ostringstream oss;
-  
+
   if (vectorize_) {
     std::string symb0 = unique_fp_name();
     std::string symb1 = unique_fp_name();
@@ -400,7 +401,7 @@ CppCodeContext::assign_binary_expr_(const std::string& name,
       << symbol_to_pointer(right) << end_of_stat() << endl;
       oss << "__assume_aligned(" << symb2 << ", 16)" << end_of_stat() << endl;
     }
-    
+
     oss << start_expr();
     oss << symb0 << "[v]" << (accum ? " += " : " = ")
     << (symb1_is_a_const ? left : symb1)
@@ -536,7 +537,7 @@ CppCodeContext::symbol_to_pointer(const std::string& symbol)
     oss << "(&(" << symbol << "))";
     return oss.str();
   }
-  
+
   // if this quantity is a part of Libint_t then the symbol is a vector
   // otherwise it's a constant
   loc = symbol.find("inteval");
@@ -663,8 +664,8 @@ SafePtr<ForLoop>
 CppCodeContext::for_loop(std::string& varname, const SafePtr<Entity>& less_than,
                          const SafePtr<Entity>& start_at) const
 {
-  // no implemented
-  assert(false);
+  // not implemented
+  abort();
 }
 
 std::string
