@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -24,8 +24,6 @@
 #include <generic_rr.h>
 #include <r12kg12_11_11.h>
 
-using namespace std;
-
 namespace libint2 {
 
     /** VRR Recurrence Relation for 2-e integrals of the R12_k_G12 operators.
@@ -63,11 +61,11 @@ namespace libint2 {
       /** Re-Implementation of GenericRecurrenceRelation::generate_label():
           R12kG12 VRR recurrence relations codes are independent of m (it never appears anywhere in equations), hence
           to avoid generating identical code make sure that the (unique) label does not contain m. */
-      std::string generate_label() const
+      std::string generate_label() const override
       {
         typedef typename TargetType::AuxIndexType mType;
         static SafePtr<mType> aux0(new mType(0u));
-        ostringstream os;
+        std::ostringstream os;
         os << descr() << "P" << part << to_string(where)
            << genintegralset_label(target_->bra(),target_->ket(),aux0,target_->oper());
         return os.str();
@@ -75,11 +73,11 @@ namespace libint2 {
 
   #if LIBINT_ENABLE_GENERIC_CODE
       /// Implementation of RecurrenceRelation::has_generic()
-      bool has_generic(const SafePtr<CompilationParameters>& cparams) const;
+      bool has_generic(const SafePtr<CompilationParameters>& cparams) const override;
       /// Implementation of RecurrenceRelation::generic_header()
-      std::string generic_header() const;
+      std::string generic_header() const override;
       /// Implementation of RecurrenceRelation::generic_instance()
-      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const;
+      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const override;
   #endif
     };
 
@@ -115,11 +113,11 @@ namespace libint2 {
         const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
         const OriginDerivative<3u> dC = Tint->bra(1,0).deriv();
         const OriginDerivative<3u> dD = Tint->ket(1,0).deriv();
-        const bool deriv = dA.zero() == false ||
-            dB.zero() == false ||
-            dC.zero() == false ||
-            dD.zero() == false;
-        assert(deriv == false);
+        const bool deriv = !dA.zero() ||
+            !dB.zero() ||
+            !dC.zero() ||
+            !dD.zero();
+        assert(!deriv);
 
 
         typedef TargetType ChildType;
@@ -507,7 +505,7 @@ namespace libint2 {
           unit_s = sh_a.is_unit();
         }
 
-        oss << "using namespace libint2;" << endl;
+        oss << "using namespace libint2;" << std::endl;
         if (K == -1) {
           if (xsxs) {
             oss << "libint2::OSVRR_xs_xs<" << part << "," << sh_a.norm() << "," << sh_c.norm() << ",";
