@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -25,8 +25,6 @@
 #include <generic_rr.h>
 #include <onep_1_1.h>
 
-using namespace std;
-
 namespace libint2 {
 
   /** VRR Recurrence Relation for 1-e overlap integrals.
@@ -83,8 +81,8 @@ namespace libint2 {
       // if derivative integrals, there will be extra terms (Eq. (143) in Obara & Saika JCP 89)
       const OriginDerivative<3u> dA = Tint->bra(0,0).deriv();
       const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero();
 
       typedef TargetType ChildType;
       ChildFactory<ThisType,ChildType> factory(this);
@@ -228,8 +226,8 @@ namespace libint2 {
       // if derivative integrals, there will be extra terms (Eq. (143) in Obara & Saika JCP 89)
       const OriginDerivative<1u> dA = Tint->bra(0,0).deriv();
       const OriginDerivative<1u> dB = Tint->ket(0,0).deriv();
-      const bool deriv = dA.zero() == false ||
-                         dB.zero() == false;
+      const bool deriv = !dA.zero() ||
+                         !dB.zero();
 
       typedef TargetType ChildType;
       ChildFactory<ThisType,ChildType> factory(this);
@@ -374,8 +372,8 @@ namespace libint2 {
       // if derivative integrals, there will be extra terms (Eq. (143) in Obara & Saika JCP 89)
       const OriginDerivative<3u> dA = Tint->bra(0,0).deriv();
       const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero();
 
       typedef TargetType Child1Type;
       ChildFactory<ThisType,Child1Type> factory(this);
@@ -529,11 +527,11 @@ namespace libint2 {
       /** Re-Implementation of GenericRecurrenceRelation::generate_label():
           ElecPot VRR recurrence relation is invariant of m, hence
           to avoid generating identical code make sure that the (unique) label has m=0. */
-      std::string generate_label() const
+      std::string generate_label() const override
       {
         typedef typename TargetType::AuxIndexType mType;
         static SafePtr<mType> aux0(new mType(0u));
-        ostringstream os;
+        std::ostringstream os;
         os << descr() <<  to_string(where)
            << genintegralset_label(target_->bra(),target_->ket(),aux0,target_->oper());
         return os.str();
@@ -562,8 +560,8 @@ namespace libint2 {
       // if derivative integrals, there will be extra terms (Eq. (143) in Obara & Saika JCP 89)
       const OriginDerivative<3u> dA = Tint->bra(0,0).deriv();
       const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero();
 
       typedef TargetType ChildType;
       ChildFactory<ThisType,ChildType> factory(this);
@@ -712,8 +710,8 @@ namespace libint2 {
           // J.M. Pérez-Jordá and W. Yang, J Chem Phys 104, 8003 (1996), Eqs. (23-27) for multipole quanta
           const OriginDerivative<3u> dA = Tint->bra(0,0).deriv();
           const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
-          const bool deriv = dA.zero() == false ||
-              dB.zero() == false;
+          const bool deriv = !dA.zero() ||
+              !dB.zero();
           if (deriv)  // derivative relations not yet implemented
             return;
 
