@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2020 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -39,9 +39,14 @@
 using namespace std;
 using namespace libint2;
 
-const double ABSOLUTE_DEVIATION_THRESHOLD = 1.0E-15; // indicate failure if any integral differs in absolute sense by more than this
+const double ABSOLUTE_DEVIATION_THRESHOLD = 5.0E-14; // indicate failure if any integral differs in absolute sense by more than this
+                                                     // loss of precision in HRR likely limits precision for high-L (e.g. (dp|dd), (dd|dd), etc.)
 const double RELATIVE_DEVIATION_THRESHOLD = 1.0E-9; // indicate failure if any integral differs in relative sense by more than this
 
+double absolute_derivation_threshold(int deriv_order) {
+  return ABSOLUTE_DEVIATION_THRESHOLD * std::pow(3., deriv_order > 2 ? deriv_order-2 : 0);
+}
+
 /// change to true to skip verification and do some timing simulation
 const bool do_timing_only = false;
 
@@ -68,15 +73,15 @@ namespace {
 
 // test 4, 3, and 2-center integrals
 #ifdef INCLUDE_ERI
-void test_4eri(unsigned int deriv_order,
+bool test_4eri(unsigned int deriv_order,
                unsigned int lmax_max);
 #endif
 #ifdef INCLUDE_ERI3
-void test_3eri(unsigned int deriv_order,
+bool test_3eri(unsigned int deriv_order,
                unsigned int lmax_max);
 #endif
 #ifdef INCLUDE_ERI2
-void test_2eri(unsigned int deriv_order,
+bool test_2eri(unsigned int deriv_order,
                unsigned int lmax_max);
 #endif
 
@@ -89,28 +94,34 @@ int main(int argc, char** argv) {
   // static initialization of the library (only needs to happen once per process)
   LIBINT2_PREFIXED_NAME(libint2_static_init)();
 
+  bool success = true;
   // run the tests
 #ifdef INCLUDE_ERI
-  test_4eri(deriv_order, lmax_max);
+  if (deriv_order <= 4)
+    success &= test_4eri(deriv_order, lmax_max);
 #endif
 #ifdef INCLUDE_ERI3
-  test_3eri(deriv_order, lmax_max);
+  if (deriv_order <= 4)
+    success &= test_3eri(deriv_order, lmax_max);
 #endif
 #ifdef INCLUDE_ERI2
-  test_2eri(deriv_order, lmax_max);
+  if (deriv_order <= 4)
+    success &= test_2eri(deriv_order, lmax_max);
 #endif
 
   // cleanup static library data (once per process)
   LIBINT2_PREFIXED_NAME(libint2_static_cleanup)();
 
-  return 0;
+  return success ? 0 : 1;
 }
 
 #ifdef INCLUDE_ERI
-void test_4eri(unsigned int deriv_order,
+bool test_4eri(unsigned int deriv_order,
                unsigned int lmax_max) {
 
-  if (deriv_order > INCLUDE_ERI) return;
+  if (deriv_order > INCLUDE_ERI) return true;
+
+  bool test_success = true;
 
   // record start wall time
   struct timeval tod;
@@ -130,6 +141,12 @@ void test_4eri(unsigned int deriv_order,
 #endif
 #if INCLUDE_ERI >= 2
   if (deriv_order == 2) lmax = LIBINT2_MAX_AM_eri2;
+#endif
+#if INCLUDE_ERI >= 3
+  if (deriv_order == 3) lmax = LIBINT2_MAX_AM_eri3;
+#endif
+#if INCLUDE_ERI >= 4
+  if (deriv_order == 4) lmax = LIBINT2_MAX_AM_eri4;
 #endif
   Libint_t* inteval = libint2::malloc<Libint_t>(max_contrdepth4);
   if (deriv_order == 0) LIBINT2_PREFIXED_NAME(libint2_init_eri)(&inteval[0], lmax, 0);
@@ -139,6 +156,12 @@ void test_4eri(unsigned int deriv_order,
 #if INCLUDE_ERI >= 2
   if (deriv_order == 2) LIBINT2_PREFIXED_NAME(libint2_init_eri2)(&inteval[0], lmax, 0);
 #endif
+#if INCLUDE_ERI >= 3
+  if (deriv_order == 3) LIBINT2_PREFIXED_NAME(libint2_init_eri3)(&inteval[0], lmax, 0);
+#endif
+#if INCLUDE_ERI >= 4
+  if (deriv_order == 4) LIBINT2_PREFIXED_NAME(libint2_init_eri4)(&inteval[0], lmax, 0);
+#endif
 #ifdef LIBINT2_FLOP_COUNT
   LIBINT2_PREFIXED_NAME(libint2_init_flopcounter)(&inteval[0], max_contrdepth4);
 #endif
@@ -176,6 +199,14 @@ void test_4eri(unsigned int deriv_order,
           if (deriv_order == 2 && LIBINT2_PREFIXED_NAME(libint2_build_eri2)[l0][l1][l2][l3] == 0)
             continue;
 #endif
+#if INCLUDE_ERI >= 3
+          if (deriv_order == 3 && LIBINT2_PREFIXED_NAME(libint2_build_eri3)[l0][l1][l2][l3] == 0)
+            continue;
+#endif
+#if INCLUDE_ERI >= 4
+          if (deriv_order == 4 && LIBINT2_PREFIXED_NAME(libint2_build_eri4)[l0][l1][l2][l3] == 0)
+            continue;
+#endif
 
           unsigned int am[4];
           am[0] = l0;
@@ -231,6 +262,14 @@ void test_4eri(unsigned int deriv_order,
           else if (deriv_order == 2)
             LIBINT2_PREFIXED_NAME(libint2_build_eri2)[am[0]][am[1]][am[2]][am[3]](&inteval[0]);
 #endif
+#if INCLUDE_ERI >= 3
+          else if (deriv_order == 3)
+            LIBINT2_PREFIXED_NAME(libint2_build_eri3)[am[0]][am[1]][am[2]][am[3]](&inteval[0]);
+#endif
+#if INCLUDE_ERI >= 4
+          else if (deriv_order == 4)
+            LIBINT2_PREFIXED_NAME(libint2_build_eri4)[am[0]][am[1]][am[2]][am[3]](&inteval[0]);
+#endif
 #endif
 #if LIBINT_CONTRACTED_INTS
           inteval[0].contrdepth = contrdepth4;
@@ -248,6 +287,16 @@ void test_4eri(unsigned int deriv_order,
             LIBINT2_PREFIXED_NAME(libint2_build_eri2)[am[0]][am[1]][am[2]][am[3]](
                 &inteval[0]);
 #endif
+#if INCLUDE_ERI >= 3
+          else if (deriv_order == 3)
+            LIBINT2_PREFIXED_NAME(libint2_build_eri3)[am[0]][am[1]][am[2]][am[3]](
+                &inteval[0]);
+#endif
+#if INCLUDE_ERI >= 4
+          else if (deriv_order == 4)
+            LIBINT2_PREFIXED_NAME(libint2_build_eri4)[am[0]][am[1]][am[2]][am[3]](
+                &inteval[0]);
+#endif
 
 
           if (not do_timing_only) {
@@ -325,11 +374,13 @@ void test_4eri(unsigned int deriv_order,
                     for (unsigned int di = 0; di < nderiv; ++di) {
                       const LIBINT2_REF_REALTYPE abs_error = abs(ref_eri[di] - LIBINT2_REF_REALTYPE(new_eri[di]));
                       const LIBINT2_REF_REALTYPE relabs_error = abs(abs_error / ref_eri[di]);
-                      if (relabs_error > RELATIVE_DEVIATION_THRESHOLD && abs_error > ABSOLUTE_DEVIATION_THRESHOLD) {
+                      if (relabs_error > RELATIVE_DEVIATION_THRESHOLD &&
+                          abs_error > absolute_derivation_threshold(deriv_order)) {
                         std::cout << "Elem " << ijkl << " di= " << di << " v="
                             << v << " : ref = " << ref_eri[di]
                             << " libint = " << new_eri[di]
-                            << " relabs_error = " << relabs_error << endl;
+                            << " relabs_error = " << relabs_error
+                            << " abs_error = " << abs_error << endl;
                         success = false;
                       }
                     }
@@ -343,6 +394,7 @@ void test_4eri(unsigned int deriv_order,
 
           cout << (success ? "ok" : "failed") << std::endl;
 
+          test_success &= success;
           } // checking computed values vs. the reference
 
           } // end of nrepeats
@@ -363,11 +415,19 @@ void test_4eri(unsigned int deriv_order,
     LIBINT2_PREFIXED_NAME(libint2_cleanup_eri)(&inteval[0]);
 #if INCLUDE_ERI >= 1
   if (deriv_order == 1)
-    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri)(&inteval[0]);
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri1)(&inteval[0]);
 #endif
 #if INCLUDE_ERI >= 2
   if (deriv_order == 2)
-    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri)(&inteval[0]);
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri2)(&inteval[0]);
+#endif
+#if INCLUDE_ERI >= 3
+  if (deriv_order == 3)
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri3)(&inteval[0]);
+#endif
+#if INCLUDE_ERI >= 4
+  if (deriv_order == 4)
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_eri4)(&inteval[0]);
 #endif
   free(inteval);
 
@@ -375,14 +435,18 @@ void test_4eri(unsigned int deriv_order,
   gettimeofday(&tod,0);
   const double end_wall_time = tod.tv_sec + 0.000001 * tod.tv_usec;
   std::cout << "wall time = " << (end_wall_time - start_wall_time) << " seconds" << std::endl;
+
+  return test_success;
 }
 #endif // INCLUDE_ERI
 
 #ifdef INCLUDE_ERI3
-void test_3eri(unsigned int deriv_order,
+bool test_3eri(unsigned int deriv_order,
                unsigned int lmax_max) {
 
-  if (deriv_order > INCLUDE_ERI3) return;
+  if (deriv_order > INCLUDE_ERI3) return true;
+
+  bool test_success = true;
 
   // record start wall time
   struct timeval tod;
@@ -402,6 +466,12 @@ void test_3eri(unsigned int deriv_order,
 #if defined(LIBINT2_MAX_AM2)
   if (deriv_order == 2) lmax_default = LIBINT2_MAX_AM2;
 #endif
+#if defined(LIBINT2_MAX_AM3)
+  if (deriv_order == 3) lmax_default = LIBINT2_MAX_AM3;
+#endif
+#if defined(LIBINT2_MAX_AM4)
+  if (deriv_order == 4) lmax_default = LIBINT2_MAX_AM4;
+#endif
 
   unsigned int lmax;
   if (deriv_order == 0) lmax = LIBINT2_MAX_AM_3eri;
@@ -410,6 +480,12 @@ void test_3eri(unsigned int deriv_order,
 #endif
 #if INCLUDE_ERI3 >= 2
   if (deriv_order == 2) lmax = LIBINT2_MAX_AM_3eri2;
+#endif
+#if INCLUDE_ERI3 >= 3
+  if (deriv_order == 3) lmax = LIBINT2_MAX_AM_3eri3;
+#endif
+#if INCLUDE_ERI3 >= 4
+  if (deriv_order == 4) lmax = LIBINT2_MAX_AM_3eri4;
 #endif
   Libint_t* inteval = libint2::malloc<Libint_t>(max_contrdepth3);
   if (deriv_order == 0)
@@ -422,6 +498,14 @@ void test_3eri(unsigned int deriv_order,
   if (deriv_order == 2)
     LIBINT2_PREFIXED_NAME(libint2_init_3eri2)(&inteval[0], lmax, 0);
 #endif
+#if INCLUDE_ERI3 >= 3
+  if (deriv_order == 3)
+    LIBINT2_PREFIXED_NAME(libint2_init_3eri3)(&inteval[0], lmax, 0);
+#endif
+#if INCLUDE_ERI3 >= 4
+  if (deriv_order == 4)
+    LIBINT2_PREFIXED_NAME(libint2_init_3eri4)(&inteval[0], lmax, 0);
+#endif
 #ifdef LIBINT2_FLOP_COUNT
   LIBINT2_PREFIXED_NAME(libint2_init_flopcounter)(&inteval[0], max_contrdepth3);
 #endif
@@ -455,6 +539,14 @@ void test_3eri(unsigned int deriv_order,
         if (deriv_order == 2 && LIBINT2_PREFIXED_NAME(libint2_build_3eri2)[l0][l1][l2] == 0)
           continue;
 #endif
+#if INCLUDE_ERI3 >= 3
+        if (deriv_order == 3 && LIBINT2_PREFIXED_NAME(libint2_build_3eri3)[l0][l1][l2] == 0)
+          continue;
+#endif
+#if INCLUDE_ERI3 >= 4
+        if (deriv_order == 4 && LIBINT2_PREFIXED_NAME(libint2_build_3eri4)[l0][l1][l2] == 0)
+          continue;
+#endif
 
 #if LIBINT_CONTRACTED_INTS
         const uint contrdepth = do_timing_only ? std::min((3*lmax+3) / (l0+l1+l2+3), max_contrdepth) : max_contrdepth;
@@ -512,6 +604,14 @@ void test_3eri(unsigned int deriv_order,
         if (deriv_order == 2)
           LIBINT2_PREFIXED_NAME(libint2_build_3eri2)[am[0]][am[1]][am[2]](&inteval[0]);
 #endif
+#if INCLUDE_ERI3 >= 3
+        if (deriv_order == 3)
+          LIBINT2_PREFIXED_NAME(libint2_build_3eri3)[am[0]][am[1]][am[2]](&inteval[0]);
+#endif
+#if INCLUDE_ERI3 >= 4
+        if (deriv_order == 4)
+          LIBINT2_PREFIXED_NAME(libint2_build_3eri4)[am[0]][am[1]][am[2]](&inteval[0]);
+#endif
 #endif
 #if LIBINT_CONTRACTED_INTS
         inteval[0].contrdepth = contrdepth3;
@@ -526,6 +626,14 @@ void test_3eri(unsigned int deriv_order,
         if (deriv_order == 2)
           LIBINT2_PREFIXED_NAME(libint2_build_3eri2)[am[0]][am[1]][am[2]](&inteval[0]);
 #endif
+#if INCLUDE_ERI3 >= 3
+        if (deriv_order == 3)
+          LIBINT2_PREFIXED_NAME(libint2_build_3eri3)[am[0]][am[1]][am[2]](&inteval[0]);
+#endif
+#if INCLUDE_ERI3 >= 4
+        if (deriv_order == 4)
+          LIBINT2_PREFIXED_NAME(libint2_build_3eri4)[am[0]][am[1]][am[2]](&inteval[0]);
+#endif
 
         if (not do_timing_only) {
 
@@ -593,7 +701,8 @@ void test_3eri(unsigned int deriv_order,
                 for (unsigned int di = 0; di < nderiv; ++di) {
                   const LIBINT2_REF_REALTYPE abs_error = abs(ref_eri[di] - LIBINT2_REF_REALTYPE(new_eri[di]));
                   const LIBINT2_REF_REALTYPE relabs_error = abs(abs_error / ref_eri[di]);
-                  if (relabs_error > RELATIVE_DEVIATION_THRESHOLD && abs_error > ABSOLUTE_DEVIATION_THRESHOLD) {
+                  if (relabs_error > RELATIVE_DEVIATION_THRESHOLD &&
+                      abs_error > absolute_derivation_threshold(deriv_order)) {
                     std::cout << "Elem " << ijk << " di= " << di << " v="
                         << v << " : ref = " << ref_eri[di]
                         << " libint = " << new_eri[di]
@@ -610,6 +719,7 @@ void test_3eri(unsigned int deriv_order,
 
         cout << (success ? "ok" : "failed") << endl;
 
+        test_success &= success;
         } // checking computed values vs. the reference
 
         } // end of nrepeats
@@ -634,6 +744,14 @@ void test_3eri(unsigned int deriv_order,
 #if INCLUDE_ERI3 >= 2
   if (deriv_order == 2)
     LIBINT2_PREFIXED_NAME(libint2_cleanup_3eri2)(&inteval[0]);
+#endif
+#if INCLUDE_ERI3 >= 3
+  if (deriv_order == 3)
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_3eri3)(&inteval[0]);
+#endif
+#if INCLUDE_ERI3 >= 4
+  if (deriv_order == 4)
+    LIBINT2_PREFIXED_NAME(libint2_cleanup_3eri4)(&inteval[0]);
 #endif
   free(inteval);
 
@@ -641,14 +759,18 @@ void test_3eri(unsigned int deriv_order,
   gettimeofday(&tod,0);
   const double end_wall_time = tod.tv_sec + 0.000001 * tod.tv_usec;
   std::cout << "wall time = " << (end_wall_time - start_wall_time) << " seconds" << std::endl;
+
+  return test_success;
 }
 #endif // INCLUDE_ERI3
 
 #ifdef INCLUDE_ERI2
-void test_2eri(unsigned int deriv_order,
+bool test_2eri(unsigned int deriv_order,
                unsigned int lmax_max) {
 
-  if (deriv_order > INCLUDE_ERI2) return;
+  if (deriv_order > INCLUDE_ERI2) return true;
+
+  bool test_success = true;
 
   typedef unsigned int uint;
 
@@ -667,6 +789,12 @@ void test_2eri(unsigned int deriv_order,
 #endif
 #if INCLUDE_ERI2 >= 2
   if (deriv_order == 2) lmax = LIBINT2_MAX_AM_2eri2;
+#endif
+#if INCLUDE_ERI2 >= 3
+  if (deriv_order == 3) lmax = LIBINT2_MAX_AM_2eri3;
+#endif
+#if INCLUDE_ERI2 >= 4
+  if (deriv_order == 4) lmax = LIBINT2_MAX_AM_2eri4;
 #endif
   Libint_t* inteval = libint2::malloc<Libint_t>(contrdepth2);
   if (deriv_order == 0)
@@ -679,6 +807,14 @@ void test_2eri(unsigned int deriv_order,
   if (deriv_order == 2)
     LIBINT2_PREFIXED_NAME(libint2_init_2eri2)(&inteval[0], lmax, 0);
 #endif
+#if INCLUDE_ERI2 >= 3
+  if (deriv_order == 3)
+    LIBINT2_PREFIXED_NAME(libint2_init_2eri3)(&inteval[0], lmax, 0);
+#endif
+#if INCLUDE_ERI2 >= 4
+  if (deriv_order == 4)
+    LIBINT2_PREFIXED_NAME(libint2_init_2eri4)(&inteval[0], lmax, 0);
+#endif
 #ifdef LIBINT2_FLOP_COUNT
   LIBINT2_PREFIXED_NAME(libint2_init_flopcounter)(&inteval[0], contrdepth2);
 #endif
@@ -704,6 +840,14 @@ void test_2eri(unsigned int deriv_order,
         if (deriv_order == 2 && LIBINT2_PREFIXED_NAME(libint2_build_2eri2)[l0][l1] == 0)
           continue;
 #endif
+#if INCLUDE_ERI2 >= 3
+        if (deriv_order == 3 && LIBINT2_PREFIXED_NAME(libint2_build_2eri3)[l0][l1] == 0)
+          continue;
+#endif
+#if INCLUDE_ERI2 >= 4
+        if (deriv_order == 4 && LIBINT2_PREFIXED_NAME(libint2_build_2eri4)[l0][l1] == 0)
+          continue;
+#endif
 
         unsigned int am[2];
         am[0] = l0;
@@ -741,6 +885,14 @@ void test_2eri(unsigned int deriv_order,
         if (deriv_order == 2)
           LIBINT2_PREFIXED_NAME(libint2_build_2eri2)[am[0]][am[1]](&inteval[0]);
 #endif
+#if INCLUDE_ERI2 >= 3
+        if (deriv_order == 3)
+          LIBINT2_PREFIXED_NAME(libint2_build_2eri3)[am[0]][am[1]](&inteval[0]);
+#endif
+#if INCLUDE_ERI2 >= 4
+        if (deriv_order == 4)
+          LIBINT2_PREFIXED_NAME(libint2_build_2eri4)[am[0]][am[1]](&inteval[0]);
+#endif
 #endif
 #if LIBINT_CONTRACTED_INTS
         inteval[0].contrdepth = contrdepth2;
@@ -755,6 +907,14 @@ void test_2eri(unsigned int deriv_order,
         if (deriv_order == 2)
           LIBINT2_PREFIXED_NAME(libint2_build_2eri2)[am[0]][am[1]](&inteval[0]);
 #endif
+#if INCLUDE_ERI2 >= 3
+        if (deriv_order == 3)
+          LIBINT2_PREFIXED_NAME(libint2_build_2eri3)[am[0]][am[1]](&inteval[0]);
+#endif
+#if INCLUDE_ERI2 >= 4
+        if (deriv_order == 4)
+          LIBINT2_PREFIXED_NAME(libint2_build_2eri4)[am[0]][am[1]](&inteval[0]);
+#endif
 
         bool success = true;
         int ij = 0;
@@ -814,7 +974,8 @@ void test_2eri(unsigned int deriv_order,
                 for (unsigned int di = 0; di < nderiv; ++di) {
                   const LIBINT2_REF_REALTYPE abs_error = abs(ref_eri[di] - new_eri[di]);
                   const LIBINT2_REF_REALTYPE relabs_error = abs(abs_error / ref_eri[di]);
-                  if (relabs_error > RELATIVE_DEVIATION_THRESHOLD && abs_error > ABSOLUTE_DEVIATION_THRESHOLD) {
+                  if (relabs_error > RELATIVE_DEVIATION_THRESHOLD &&
+                      abs_error > absolute_derivation_threshold(deriv_order)) {
                     std::cout << "Elem " << ij << " di= " << di << " v="
                         << v << " : ref = " << ref_eri[di]
                         << " libint = " << new_eri[di]
@@ -830,6 +991,7 @@ void test_2eri(unsigned int deriv_order,
 
         cout << (success ? "ok" : "failed") << endl;
 
+        test_success &= success;
     }
   }
 
@@ -839,8 +1001,15 @@ void test_2eri(unsigned int deriv_order,
 #endif
 #if INCLUDE_ERI2 >= 2
   if (deriv_order == 2) LIBINT2_PREFIXED_NAME(libint2_cleanup_2eri2)(&inteval[0]);
+#endif
+#if INCLUDE_ERI2 >= 3
+  if (deriv_order == 3) LIBINT2_PREFIXED_NAME(libint2_cleanup_2eri3)(&inteval[0]);
+#endif
+#if INCLUDE_ERI2 >= 4
+  if (deriv_order == 4) LIBINT2_PREFIXED_NAME(libint2_cleanup_2eri4)(&inteval[0]);
 #endif
   free(inteval);
 
+  return test_success;
 }
 #endif // INCLUDE_ERI2
