@@ -70,7 +70,7 @@ int merge_deriv2(int natoms, int d1, int d2) {
 template <unsigned int deriv_order>
 void validate4(const BasisSet& obs, const std::vector<Atom>& atoms) {
 #ifdef LIBINT2_SUPPORT_ERI
-  constexpr const int ncenters = 4;
+  constexpr int ncenters = 4;
   const auto max_l = obs.max_l();
   if (deriv_order > LIBINT2_DERIV_ERI_ORDER)
     return;
@@ -217,7 +217,7 @@ void validate4(const BasisSet& obs, const std::vector<Atom>& atoms) {
 template <unsigned int deriv_order>
 void validate3(const BasisSet& obs, const BasisSet& dfbs, const std::vector<Atom>& atoms) {
 #if defined(LIBINT2_SUPPORT_ERI) && defined(LIBINT2_SUPPORT_ERI3)
-  constexpr const int ncenters = 3;
+  constexpr int ncenters = 3;
   const auto max_l = std::max(obs.max_l(), dfbs.max_l());
   if (deriv_order > LIBINT2_DERIV_ERI_ORDER || deriv_order > LIBINT2_DERIV_ERI3_ORDER)
     return;
@@ -372,7 +372,7 @@ void validate3(const BasisSet& obs, const BasisSet& dfbs, const std::vector<Atom
 template <unsigned int deriv_order>
 void validate2(const BasisSet& obs, const std::vector<Atom>& atoms) {
 #if defined(LIBINT2_SUPPORT_ERI) && defined(LIBINT2_SUPPORT_ERI2)
-  constexpr const int ncenters = 2;
+  constexpr int ncenters = 2;
   if (deriv_order > LIBINT2_DERIV_ERI_ORDER || deriv_order > LIBINT2_DERIV_ERI2_ORDER)
     return;
   switch(deriv_order) {
